package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````@B4```````!``````````#"Q````
M`````````$``.``*`$``&``7``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````9`````````!D``````````0`````````!````
M!````````````````````````````````````#@8````````.!@`````````
M$`````````$````%`````"``````````(``````````@````````230`````
M``!)-``````````0`````````0````0`````8`````````!@`````````&``
M```````P0P```````#!#`````````!`````````!````!@```!BL````````
M&+P````````8O````````$@$````````\!0`````````$`````````(````&
M````0*P```````!`O````````$"\````````H`$```````"@`0````````@`
M````````4.5T9`0```!4G0```````%2=````````5)T```````#D````````
M`.0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````&*P````````8
MO````````!B\````````Z`,```````#H`P````````$`````````+VQI8B]L
M9"UM=7-L+7@X-E\V-"YS;RXQ```````````1````00````0````(````(!P0
M``5`!((H`%`$D(8`A((A`"!)`@0)N((90;H$`@I!````0@```$8```!*````
M2P```%$```!2````5`````````!8````60```%H```!<````7@```&``````
M`````````*/I&01J?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-\0[49-1\(?_D#MEQ
M6!SZH6Q@PN4_++(!BV]"^M>'XD?&`;OCDGQ5PSS2Q+F<0&>OS&8X\HL<Q(D%
MD(@'<--#1=7L,V+;[16,)<Q6I)N6I]VC:WZIG)O19<YMX*<""FL:GE`*BA!7
MH^#[20````````````````````````````````$````2````````````````
M`````````*\!```2`````````````````````````%$!```2````````````
M`````````````!`````2`````````````````````````(X!```2````````
M`````````````````!@````2`````````````````````````!\````2````
M`````````````````````.(!```2`````````````````````````)H!```2
M`````````````````````````"@````@`````````````````````````$``
M```2`````````````````````````$8````2````````````````````````
M`$T````2`````````````````````````,P"```2````````````````````
M`````+T"```2`````````````````````````&<"```2````````````````
M``````````@"```2`````````````````````````%0````2````````````
M`````````````)P"```2`````````````````````````%L````2````````
M`````````````````&,````2`````````````````````````(4"```2````
M`````````````````````&L````2`````````````````````````'$````2
M`````````````````````````'H````@`````````````````````````+8"
M```2`````````````````````````)8````2````````````````````````
M`)L````2`````````````````````````*,"```2````````````````````
M`````#4"```2`````````````````````````*(````2````````````````
M`````````"<"```2`````````````````````````$0#```2````````````
M`````````````%D"```2`````````````````````````.L"```2````````
M`````````````````*D````2`````````````````````````.,"```2````
M`````````````````````%\!```2`````````````````````````,$````@
M`````````````````````````-<````2`````````````````````````*X"
M```2`````````````````````````$4"```2````````````````````````
M`-P````2`````````````````````````.(````@````````````````````
M`````)`"```2`````````````````````````/P````2````````````````
M`````````'\!```2``````````````````````````$!```2````````````
M`````````````'4"```2`````````````````````````&X!```2````````
M``````````````````<!```2`````````````````````````!@!```2````
M``````````````````````,"```2`````````````````````````&P````2
M`````````````````````````!0"```2`````````````````````````$X"
M```2`````````````````````````-P"```2````````````````````````
M`!X!```2`````````````````````````-0"```2````````````````````
M`````/X!```2`````````````````````````+T!```2````````````````
M`````````#(!```2`````````````````````````#D!```2````````````
M`````````````$H!```2`````````````````````````/T"```A`!4`:,``
M```````(`````````/@"```2``H`T",```````"R`0```````,\!```2``L`
M050````````!`````````(8#```2``H`WC$```````#&!0```````#($```2
M``H`XCH```````!/`````````&,#```2``H`\2P````````%`````````/`#
M```2``<``"`````````!`````````*D#```2``H`I#<````````^`P``````
M`!8$```2``H`]BP```````"@`0```````.$#```0`!4`8,``````````````
M`````'0#```2``H`5#$```````"*`````````),#```2``H`ERL````````K
M`````````)L#```2``H`]3````````!(`````````+\#```2``H`HU$`````
M``#W`````````-0#```2``H`EBX````````6`````````"T$```0`!4`"-$`
M`````````````````"D#```2``H`F"4````````D`````````/X"```1`!4`
M:,`````````(`````````/8#```2``H`K"X```````"J``````````D````1
M`!$`.+P````````(`````````/\"```A`!4`:,`````````(`````````,H#
M```1`!0`6,`````````(``````````\$```0`!0`8,``````````````````
M`.8#```0``H`@B4``````````````````.T#```2``H`55$```````!.````
M`````/,!```1`!4`<,`````````$```````````#```A`!4`:,`````````(
M`````````#(#```2``H`/3$````````7`````````+(````B````````````
M`````````````$T#```2``H`!BP```````#K`````````",$```2``H`FE(`
M``````!9`0```````-4!```1`!4`8,`````````!``````````($```2``H`
M5B\```````"?`0````````!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S
M<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P
M:60`<W1R8VUP`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D
M:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T
M<F-H<@!R96%D;&EN:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE
M7VEN9F\`97AI=`!C;&]S90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E
M860`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P
M96-I9FEC`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C
M;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R
M;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!?9FEN:0!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R
M;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H
M<F5A9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?
M;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU
M<VPM>#@V7S8T+G-O+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N
M=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P
M87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T87)T`'-H85]I;FET`'!A<E]D
M:7)N86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H85]F
M:6YA;`!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R
M;"]#3U)%````````P`````````@``````````,`````````@P`````````@`
M`````````&`````````HP`````````@`````````\F`````````PP```````
M``@`````````"V`````````XP`````````@`````````!&$```````!`P```
M``````@`````````$V````````!8P`````````@`````````N6(```````#`
MOP````````8````*``````````````#(OP````````8````9````````````
M``#0OP````````8```!=``````````````#8OP````````8````G````````
M``````#@OP````````8````L``````````````#HOP````````8````Q````
M``````````#POP````````8````R``````````````#XOP````````8````W
M```````````````XO`````````4```!4``````````````!@P`````````4`
M``!@``````````````!HP`````````4```!2``````````````!PP```````
M``4```!:``````````````#XO0````````<````!````````````````O@``
M``````<````"```````````````(O@````````<````#```````````````0
MO@````````<````$```````````````8O@````````<````%````````````
M```@O@````````<````&```````````````HO@````````<````'````````
M```````PO@````````<````(```````````````XO@````````<````)````
M``````````!`O@````````<````+``````````````!(O@````````<````,
M``````````````!0O@````````<````-``````````````!8O@````````<`
M```.``````````````!@O@````````<````/``````````````!HO@``````
M``<````0``````````````!PO@````````<````1``````````````!XO@``
M``````<````2``````````````"`O@````````<````3``````````````"(
MO@````````<````4``````````````"0O@````````<````5````````````
M``"8O@````````<````6``````````````"@O@````````<````7````````
M``````"HO@````````<````8``````````````"PO@````````<````:````
M``````````"XO@````````<````;``````````````#`O@````````<````<
M``````````````#(O@````````<````=``````````````#0O@````````<`
M```>``````````````#8O@````````<````?``````````````#@O@``````
M``<````@``````````````#HO@````````<````A``````````````#PO@``
M``````<````B``````````````#XO@````````<````C````````````````
MOP````````<````D```````````````(OP````````<````E````````````
M```0OP````````<````F```````````````8OP````````<````H````````
M```````@OP````````<````I```````````````HOP````````<````J````
M```````````POP````````<````K```````````````XOP````````<````M
M``````````````!`OP````````<````N``````````````!(OP````````<`
M```O``````````````!0OP````````<````P``````````````!8OP``````
M``<````S``````````````!@OP````````<````T``````````````!HOP``
M``````<````U``````````````!POP````````<````V``````````````!X
MOP````````<````X``````````````"`OP````````<````Y````````````
M``"(OP````````<````Z``````````````"0OP````````<````[````````
M``````"8OP````````<````\``````````````"@OP````````<````]````
M``````````"HOP````````<````^``````````````"POP````````<````_
M``````````````"XOP````````<```!`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!0Z-H&``#H]3,``%C#````_S72G0``_R74G0``#Q]``/\ETIT``&@`````
MZ>#_____)<J=``!H`0```.G0_____R7"G0``:`(```#IP/____\ENIT``&@#
M````Z;#_____);*=``!H!````.F@_____R6JG0``:`4```#ID/____\EHIT`
M`&@&````Z8#_____)9J=``!H!P```.EP_____R62G0``:`@```#I8/____\E
MBIT``&@)````Z5#_____)8*=``!H"@```.E`_____R5ZG0``:`L```#I,/__
M__\E<IT``&@,````Z2#_____)6J=``!H#0```.D0_____R5BG0``:`X```#I
M`/____\E6IT``&@/````Z?#^____)5*=``!H$````.G@_O___R5*G0``:!$`
M``#IT/[___\E0IT``&@2````Z<#^____)3J=``!H$P```.FP_O___R4RG0``
M:!0```#IH/[___\E*IT``&@5````Z9#^____)2*=``!H%@```.F`_O___R4:
MG0``:!<```#I</[___\E$IT``&@8````Z6#^____)0J=``!H&0```.E0_O__
M_R4"G0``:!H```#I0/[___\E^IP``&@;````Z3#^____)?*<``!H'````.D@
M_O___R7JG```:!T```#I$/[___\EXIP``&@>````Z0#^____)=J<``!H'P``
M`.GP_?___R72G```:"````#IX/W___\ERIP``&@A````Z=#]____)<*<``!H
M(@```.G`_?___R6ZG```:",```#IL/W___\ELIP``&@D````Z:#]____):J<
M``!H)0```.F0_?___R6BG```:"8```#I@/W___\EFIP``&@G````Z7#]____
M)9*<``!H*````.E@_?___R6*G```:"D```#I4/W___\E@IP``&@J````Z4#]
M____)7J<``!H*P```.DP_?___R5RG```:"P```#I(/W___\E:IP``&@M````
MZ1#]____)6*<``!H+@```.D`_?___R5:G```:"\```#I\/S___\E4IP``&@P
M````Z>#\____)4J<``!H,0```.G0_/___R5"G```:#(```#IP/S___\E.IP`
M`&@S````Z;#\____)3*<``!H-````.F@_/___R4JG```:#4```#ID/S___\E
M(IP``&@V````Z8#\____)1J<``!H-P```.EP_/___R42G```:#@```#I8/S_
M__\E"IP``&:0_R42G```9I#_)1*<``!FD```````````051(@^P@B7PD'$B-
M?"0<2(ET)!!(C70D$$B)5"0(2(U4)`CH6/[__TB+-?F;``!(BSWJFP``2(GR
MZ.+\__^`/4N<````=37HI/W__TB)!=VL``!(B<=(A<!U"K\!````Z"O^___H
MAO[__XL],)P``.C[_O__QH#I"0```(L]'IP``.CI_O__BST3G```@(@Z!```
M`NC7_O__@(@Z!````8M$)!R->`5(8_](P><#Z!W^__](BWPD$(M4)!S'!5JL
M```$````2(G!2(D%2*P``$B+!TB)`4B-!08^``!(B4$(2(L%H)L``$B)01!(
MC07S/0``2(E!&#'`2/_`.<)^$$R+!,>-<`-(8_9,B03QZ^F#P@-(BST6K```
M13'`2(TUS@8``$ACPDC'!,$`````Z%S\__]!B<2%P'4/2(L][JL``.AI_?__
M08G$2(L]WZL``.CJ_/__,<!(C3U].P``Z&H"``!(A<!U+DB#/;>K````=1-(
MC3T7.P``Z$\"``!(B06BJP``2(L]FZL``$B%_W0%Z'L5``!(BSV2JP``Z.W]
M___HR/K__TB#Q"!$B>!!7,-(,>U(B>=(C36QE@``2(/D\.@`````2(LW2(U7
M"$4QR4R-!9@N``!(C0U0^O__2(T]&?[__^ED_/__#Q]``$B-/9F:``!(C062
MF@``2#GX=!5(BP7NF0``2(7`=`G_X`\?@`````###Q^``````$B-/6F:``!(
MC35BF@``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!<69``!(A<!T"/_@9@\?
M1```PP\?@`````"`/4F:````#X63````54B#/8J9````2(GE0513=`Q(BSVK
MF0``Z%[]__](C07'E0``2(T=R)4``$@IPTF)Q$B+!1.:``!(P?L#2(/K`4@Y
MV',A9@\?1```2(/``4B)!?69``!!_Q3$2(L%ZID``$@YV'+EZ!C___](@ST0
MF0```'0,2(T]UW<``.CR_/__6T%<Q@6XF0```5W#9@\?1```PV9F+@\?A```
M````#Q]``$B#/?"8````="952(TUKID``$B-/9=W``!(B>7HO_S__UWIZ?[_
M_V8/'X0``````.G;_O__05=!5D%5051%,>154U%(A?]T9TR+-3F9``!-A?9T
M6TF)_4F)]TB)^(H0A-)T"H#Z/70%2/_`Z_!$*>A,B?5(8]A,BV4`387D=#!(
MB=I,B>Y,B>?HX_G__X7`=1A!@#P</7413"GU38UD'`%(P?T#08DOZP9(@\4(
MZ\=:3(G@6UU!7$%=05Y!7\-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z%G_
M__](BU0D"&1(*Q0E*````'0%Z+_[__](@\08PU532(G[2(/L&&1(BP0E*```
M`$B)1"0(,<!(C6PD!#'`2(GN2(G?Z!3___](A<!T(DAC5"0$2(L%5I@``$B-
M!-!(BU`(2(D02(72=-)(@\`(Z^Y(BT0D"&1(*P0E*````'0%Z%/[__](@\08
M6UW#059!54%455-(@>R@````9$B+!"4H````2(F$))@````QP$B%_P^$X@``
M`(`_`$B)_0^$U@```.B@]___2(U<)`A)B<5(A<`/A,````!,B>_H1_C__TB%
MP`^$GP```$R-8!-(C35K-P``3(GGZ!OX__^%P'382(TU5S<``$R)Y^@(^/__
MA<!TQ4B)[^BL^O__3(GG28G&Z*'Z__]!C7P&`DAC_^A$^/__3(GA2(GJ2(TU
M(3<``$F)QDB)QS'`Z$KZ__],B?=(B=[H__G__TR)]__`=!>+1"0@)0#P```]
M`$```'4'Z!?____K!>CL]___3(GWZ,3Y___I4/___TR)[^@W^/__2(GOZ'_Y
M__](BX0DF````&1(*P0E*````'0%Z"?Z__](@<2@````6UU!7$%=05[#2('L
MN````&1(BP0E*````$B)A"2H````,<!(C70D&$B)?"0(Z,[W__^%P'4SBU0D
M,$B+?"0(@>(`\```@?H`0```=`B!^@"@``!U%KX"````Z*'V__^%P`^4P`^V
MP.L",<!(BXPDJ````&1(*PPE*````'0%Z)WY__](@<2X````PT%6055!5%5(
MB?U32(GS2(/L$&1(BP0E*````$B)1"0(,<"`/CUU`TC_PTB)W^A3^?__2(UT
M)`1(B>])B<0QP.C6_/__28G%2(7`="=(B<?H,?G__TDYQ`^'J````#'`BA0#
M08A4!0!(_\"$TG7QZ0<!``!,BS7SE0``,<!!B<5(_\!)@WS&^`!U\D&-=0)(
M8_9(P>8#@SU)I@```'093(GWZ*_U__](B07`E0``2(7`=3GIPP```,<%)*8`
M``$```!(B??H;/;__TB%P`^$J````$ECU4R)]DB)QTC!X@/H8?;__TB)!8*5
M``!(BQ5[E0``08U%`4B82,<$P@````!$B6PD!$B)Z(H0A-)T"H#Z/70%2/_`
MZ_!(*>A(8TPD!$B+%4:5``!(F$F-?`0"3(TLRNC^]?__28E%`$B%P'0Z2&-4
M)`1(BP4AE0``2(L$T(I5`$C_Q4B)P4C_P(A0_X32=`6`^CUUZ,8!/3'2B@P3
MB`P02/_"A,EU\TB+1"0(9$@K!"4H````=`7H!OC__TB#Q!!;74%<05U!7L-0
MBSW2E```Z)WW__](BQ4^E```05A(C0V5<0``2(G'2(TU8S0``.E>]___4(L]
MIY0``.AR]___2(G'Z,'___^+/924``#H7_?__TR-!<HV``!%,<E!6DB)QTR)
MP4B-%:H+``!(C34[-```Z8KT__]!5%532('L$"```&1(BP0E*````$B)A"0(
M(```,<!,C60D!NB2]/__3(T%'#0``+X!$```3(GGB<%(C14/-```,<#H,_3_
M_X/X_W4$,<#K=TACT$B!^@`0``!V`@\+A<!XZDB-K"0'$```N@`0``!,B>=(
MB>[HL/7__TB)PX7`>,N->`%(8__HGO3__TB%P'2[2&/32#GH<PE(C0P02#G-
M<KI(.>AV"DB-3!4`2#G(<JN!^P$0``!_HXG12(G'2(GN\Z3&!!``2(NT)`@@
M``!D2"LT)2@```!T!>BK]O__2('$$"```%M=05S#Z1#___]!5T%6055)B?U(
MC3U;,P``05152(GU4TB![*@0``!D2(L$)2@```!(B80DF!```#'`Z'+Z__^^
M+P```$R)[TB)P^BD]/__2(7`=!9,B>Y(C3T?,P``,<#HJ?S__^D2`0``3(GO
M3(T]MS(``.@:]O__2(TU"C,``$B)[T&)QNBX]?__28G$387D=,%!@#PD`'4#
M38G\2(7;=!-,B>9(B=_H-O/__X7`#X2Q````3(GGZ-;U__^-2/](8]%,`>*`
M.B]U!\8"`(G(Z^M"C40P`3W_#P``#X]R____2(VL))@```!-B>E,B>$QP$R-
M!9,R``!(C15P,P``O@`0``!(B>_HAO+____`/0`0``!V`@\+2(UT)`A(B>_H
M_O3__X7`=3V+1"0@)0#P```]`(```'4MO@$```!(B>_H/?+__X7`=1Q(B>Y(
MC3TI,@``Z+7[__](B>_H0O/__TF)Q>L62(TU'3(``#'_Z,_T__])B<3I$O__
M_TB+A"28$```9$@K!"4H````=`7H#_7__TB!Q*@0``!,B>A;74%<05U!7D%?
MPTB)^(H7A-)T#$C_QX#Z+T@/1,?K[L-(A?\/A)4```!5@#\`2(G]=#SHO?3_
M_TB-5`7_2#G5<QN`.B]U$4C_RNOQ@#HO2(U"_W0I2(G"2#G5<N](.=5U'(!]
M`"](C3V!,0``=0=(C3T7,0``7>M-@#HO=0A(_\I(.=5R\T@IZDB-0@)(/0`0
M``!W)DC_PDB!^@`0``!V`@\+2(GN2(T]J)$``.@#\___2(T%G)$``.L",<!=
MPTB-/<<P``#I.O+__TB#[#A(C36_;0``N2(```!D2(L$)2@```!(B40D*#'`
M2(U\)`;SI$B-/?<P``#H3?C__S'`2(T]\C```.@_^/__,<!(C3WL,```Z#'X
M__\QP$B-/><P``#H(_C__S'`2(T]X#```.@5^/__,<!(C3WB,```Z`?X__\Q
MP$B-/8DP``#H^??__S'`2(T]TC```.CK]___,<!(C3W.,```Z-WW__\QP$B-
M/<HP``#HS_?__S'`2(T]6C```.C!]___,<!(C3VX,```Z'OW__](A<!T$4B)
MQDB-/9`P```QP.C"^?__2(T]IS```#'`Z%?W__](B<9(A<!T#DB-/:HO```Q
MP.B>^?__2(T]E3```#'`Z#/W__](C3WO+P``2(G&2(7`=1U(C3V(,```,<#H
M%O?__TB)QDB%P'0+2(T](3```#'`ZR9(C7PD%[H*````2(TU;C```.B?\/__
MA<!U$4B-="0A2(T]]R\``.@U^?__,<!(C356,```2(T]QB\``.@@^?__2(M$
M)"AD2"L$)2@```!T!>B@\O__2(/$.,.#/52/``#_=3A12(T]LB\``#'`Z)'V
M__](B<(QP$B%TG01BA*`^C`/E<$QP(32#Y7`(<B)!2*/``"+!1R/``!:PXL%
M%(\``,-1Z%WR__^)Q^BV\/__2(7`=`-(BP!:PT%4,<!)B?Q(C3W%+P``55/H
M-?;__TR)YDB%P'16@#@`2(G#=$Y(B<?H+_#__TB%P'533(GGZ/+Q__](B=](
MB<7HY_'__TB-?`4"Z(WO__](C36S+P``28G83(GB2(G%2(G'2(T-NBX``#'`
MZ(SQ__](B>Y;2(T]6"\``%TQP$%<Z2+X__];74%<PT%72(TU.8X``+D,````
M059!54%455-(B?M(@>Q8@0``9$B+!"4H````2(F$)$B!``!(C04H+P``2(U\
M)$A(QT0D*`````#SI4B-/30N``!(QT0D0`````!(B40D&$B-!=8M``!(B40D
M($B-!?4N``!(B40D,$B-!>XN``!(B40D.#'`Z#CU__](A<!T0(`X`$B)Q70X
M2(G'Z-G^__](BX0D2($``&1(*P0E*`````^%^`0``$B!Q%B!``!(B>];74%<
M05U!7D%?Z>7N__\QP$B-;"0PZ(;^__])B<1(A<!U.4B+?0!(A?]T*3'`Z,_T
M__](B<=(A<!U!DB#Q0CKXH`X`'3UZ*GN__])B<1(A<!TZ.L'3(TE/RX``$R)
MYTR-+4\N``#H>?#__TB-?``!Z!_N__])B<9(B<5!#[84)(32=!9(B>],B>XQ
MP$G_Q.@@\/__2(/%`NOA3(UL)$A-BV4`387D="Y,B><QP.A0]/__2(G%2(7`
M=".`.`!T'DB)Q^@6]O__A<!T$DB)[^@A[O__28G$3(UL)!CK,$F#Q0CKO$F+
M;0!(A>UT)H!]``!T($B)[^CC]?__A<!T"TB)[^CN[?__28G$28/%"$V%Y'31
M3(GGZ,KO__],B?=(B<7HO^___XVL!00$``!(8^U(B>_H7>W__TV)\4R-!7DM
M``!(C0V5+```2(G'28G%3(GB,<!(C35E+0``Z%7O__^^P`$``$R)[^CH[O__
M_\!U*^C/[O__1(L`08/X$70=2(L32(L]%(@``$R)Z3'`2(TU-"T``.@[[O__
MZR](C70D>$R)[^@L[?__08G&A<!T(TB+$TB+/>.'``!,B>DQP$B--3XM``#H
M"N[__T4QY.D)`P``BX0DD````"4`\```/0!```!URD2+I"24````Z!+O__]!
M.<1UN(N$))`````E_P$``#W``0``=:5(B>_H@NS__TB-/7TL``!)B<0QP.C?
M\O__2(G'2(7`=05(BROK&.B_[/__2(L[2(G&Z!KX__](B<5(A<!TXTB)[^B4
M[O__28G'@_@#?EI(F$B--?4L``!(C7P%_.C)Z___A<!U0T&#_P1T#T&#[P5-
M8_]"@'P]`"]U+DB+6PA(A=MT)4B)W^A/[O__2(/X`W872(U\`_Q(C36T+```
MZ(CK__^%P$@/1.LQP.B@^___A<`/A6D!``!(B>\Q]N@Y[/__B<6%P`^$50$`
M`+H"````2,?&[O___XG'Z"SK__](C9PD2`$``+H&````B>](B=[H%>W__X"\
M)$@!````=6.`O"1)`0``0W59@+PD2@$``$%U3X"\)$L!``!#=46`O"1,`0``
M2'4[@+PD30$``$5U,;H"````2,?&QO___XGOZ,;J__^Z*0```$B)WHGOZ+?L
M__],C0VR+```28G8Z9X````QTC'VB>_HG>K__S'`Z#L;``!)B<:Z`(```$B)
MWHGOZ(3L__](B<*%P'X-2(G>3(GWZ&4;``#KW8GO3(V\)`L!``!(C:PD'P$`
M`#';Z#?L__],B?9,B?],C37K*@``Z"\<``!)B>A!#[84'TB)[S'`3(GV2/_#
M3(E$)`A(@\4"Z,3L__](@_L43(M$)`AUU\:$)$<!````3(T-#"P``$B-#<PI
M``!,B>I,B><QP$B--4`K``#HC^S__^F0````2(TU6"H``$B-/>0I```QP.@@
M\___2(T=T"L``.C9Z?__3(T-Q"L``$R)ZDB-#8$I``!!B<!(C34)*P``3(GG
M,<#H1.S__[[``0``3(GGZ-?K____P'4YZ+[K__^#.!%U+^B4Z?__0?_&3(GJ
M3(GG08G`4#'`2(T--RD``%-%B?%(C37,*@``Z/[K__]:6>NV3(GOZ*+K__](
MC3W\*```3(GF,<#HC/+__TR)Y^C=^?__2(N$)$B!``!D2"L$)2@```!T!>@!
M[/__2('$6($``$R)X%M=05Q!74%>05_#055!5%534HL]OX@``.B*Z___BSVT
MB```2(G#Z'SK__^*D[@```!(C3W+*```B)"Y````,<#HP.___TB%P'0+@#@Q
M=0:`>`$`=`<QP.AA]___BSUUB```Z$#K__^Y"P```+H!````2(TU&2H``$B)
MQ^BWZ?__2(7`=36+/4R(``#H%^O__[D#````N@$```!(C37U*0``2(G'Z([I
M__](B<-(A<`/A<\```#I$0$``$B+0!"[`0```$B+:"@Y'8J8``"+/02(``!$
MC6/_?AKHR>K__S')26/42(GN2(G'Z'GH__](A<!U%(L%7I@``/_(1#G@=86[
M`0```.M73(LH08M%#"4`!"``/0`$``!U!DF+=1#K((L]L8<``.A\ZO__3(GN
MN0(````QTDB)Q^B:ZO__2(G&2(L5")@``$ACPTB+/,+HY.?__X7`=9S_P^EI
M____.1WSEP``BSUMAP``#XX5____Z#+J__](B>[_PTB)Q^@5Y___Z]I(BT`0
MBSU)AP``2(LHZ!'J__](C17[*```2(G'2(GNZ*_H__](BT,02(LH]D4.0'06
MBST<AP``Z.?I__](B>Y(B<?HK.?__XL]!H<``.C1Z?__N0,```"Z`0```$B-
M-<\H``!(B<?H2.C__TB)PTB%P'1\2(T]TR8``#'`Z`#N__])B<1(A<!T#TB+
M0Q"+/<"&``!(BRCK1.A,\O__BSVPA@``2(7`2(G%2(M#$'0@3(L@Z&SI__](
MB>I(B<=,B>;H#NC__TB)[^@6Z?__ZR!(BQ7UE@``2(LH3(LBZ$+I__],B>)(
MB>Y(B<?HY.?__XL]7H8``.@IZ?__N@$```!(C343*```2(G'Z#7F__^+/3^&
M``!(B<7H!^G__TB-%0LH``!(B>Y(B<?HI>?__XL]'X8``.CJZ/__2(T]!"8`
M`,:`N0`````QP.@S[?__2(D%AI8``$B%P'4D2(L]:I8``.A;]___2(D%;I8`
M`$B%P'4,2(T]NR<``.@%YO__2(L]5I8``+[``0``Z$3H__^)P8U``8/X`78D
M@_D1=!](BP4FE@``2(L5+Y8``$B-/:(G``!(BS`QP.C&Y?__6%M=05Q!7<-5
M2(G]4U'HO_/__TB)Q^BA\___2(G#,<#H]O7__X7`="I(A>UT)8!]``!T'TB-
M-4$F``!(B=_HD^;__T@YPW4+6DB)[UM=Z1?M__]86UW#05<QTD%6055!5%53
M2('LF`(``&1(BP0E*````$B)A"2(`@``,<"+1!<X2(MT%S@/R(G`2(GQ2(E$
M5`A(B?!(P>D@2,'H*$C![C@E`/\``$@)\$B)SDC!X0A(P>88@>$``/\`B?9(
M"?!("<A(B414$$B#P@A(@_I`=:Q(C50D"$B-M"0(`@``2(M":$@S0D!(@\((
M2#-""$@S0OA(C0P`2,'H'PG(2(E">$@Y\G793(L/3(M?$$B+=R!(BU\83(G(
M3(G*2(MO"$C!ZAM(P>`%2`G0`T0D"(V4,)EY@EI,B=A(BW0D$$@QV$@AZ$B-
MM#.9>8):2#'81(TD`DB)ZDB)Z$C!Z`)(P>(>38G@2`G"3(G82<'H&XG12#'(
M3"'(3#'82`'P3(GF2,'F!4P)QD2--#!,B<Y,B<A(P>8>2,'H`DV)\D@)\$B+
M="082<'J&T@QPD&)P$PAXDF-M#.9>8):2#'*2`'R3(GV2,'F!4P)UD2-%#),
MB>9)P>P"2(M4)"!(P>8>3`GF2(V4$9EY@EI,B=%(,?!!B?5,(?!,,<!(P>D;
M2`'03(G22,'B!4@)RDR)\4G![@)(P>$>1(TD$$B+1"0H3`GQ3(GB2#'.28V$
M`)EY@EI(P>H;08G.3"'63#'N2`'&3(G@2,'@!4@)T$R)TDG!Z@)(P>(>1(T$
M!DB+1"0P3`G23(G&2#'128V$!9EY@EI(P>X;08G23"'A3#'Q2`'!3(G`2,'@
M!4@)\$2-+`%,B>!)P>P"2(M,)#A(P>`>3(GN3`G@28V,#IEY@EI(,<)!B<1,
M(<),,=)(`<I,B>E(P>$%2,'N&T@)\4R)QDG!Z`)(P>8>1(TT"DB+5"1`3`G&
M3(GQ2#'P28V4$IEY@EI(P>D;08GP3"'H3#'@2`'03(GR2,'B!4@)RDR)Z4G!
M[0)(P>$>1(T4$$B+1"1(3`GI3(G22#'.28V$!)EY@EI(P>H;08G-3"'V3#'&
M2`'&3(G02,'@!4@)T$R)\DG![@)(P>(>1(TD!DB+1"103`GR3(GF2#'128V$
M`)EY@EI(P>X;08G63"'13#'I2`'!3(G@2,'@!4@)\$2-!`%,B=!)P>H"2(M,
M)%A(P>`>3(G&3`G028V,#9EY@EI(P>X;2#'"08G"3"'B3#'R2`'*3(G!2,'A
M!4@)\4R)YDG![`)(P>8>1(TL"DB+5"1@3`GF3(GI2#'P28V4%IEY@EI(P>D;
M08GT3"'`3#'02`'03(GJ2,'B!4@)RDR)P4G!Z`)(P>$>1(TT$$B+1"1H3`G!
M3(GR2#'.28V$`IEY@EI(P>H;08G(3"'N3#'F2`'&3(GP2,'@!4@)T$R)ZDC!
MXAY)P>T"1(T4!DB+1"1P3`GJ3(G62#'128V$!)EY@EI(P>X;08G53"'Q3#'!
M2`'!3(G02,'@!4@)\$2-)`%,B?!)P>X"2(M,)'A(P>`>3(GF3`GP28V,")EY
M@EI(P>X;2#'"08G&3"'23#'J2`'*3(GA2,'A!4@)\4R)UDG!Z@)(P>8>1(T$
M"DB+E"2`````3`G63(G!2#'P28V4%9EY@EI(P>D;08GR3"'@3#'P2`'03(G"
M2,'B!4@)RDR)X4G![`)(P>$>1(TL$$B+A"2(````3`GA3(GJ2#'.28V$!IEY
M@EI(P>H;08G,3"'&3#'62`'&3(GH2,'@!4@)T$R)PDG!Z`)(P>(>1(TT!DB+
MA"20````3`G"3(GV2#'128V$`IEY@EI(P>X;08G03"'I3#'A2`'!3(GP2,'@
M!4@)\$2-%`%,B>A)P>T"2(N,))@```!(P>`>3`GH28V,#)EY@EI-B=1(,<))
MP>P;B<9,(?),,<)(`=%,B=)(P>(%3`GB38GT2<'N`DG!Y!Z)TDT)]$@!RDB+
MC"2@````3#'@08G53"'028V,")EY@EI-B>A(,?!)P>@;2`'!3(GH2,'@!4P)
MP(G`2`'(3(G12<'J`DC!X1Y!B<!,"=%-B>)%B>1,`Z0DL````$DQRD0QTDR+
ME"2H````2HVT%J'KV6Y-B<)(`?),B<9)P>H;2,'F!4P)UDV)ZDG![0))P>(>
MB?9-">I)B<U(`?*)R4TQU8G62`.,)+@```!$,>A)B?5-C:0$H>O9;DB)\$G!
M[1M(P>`%3`GHB<!-C2P$3(G`2<'H`DC!X!Y%B>Q,"<!-B=!%B=)),<!$,<),
MC801H>O9;DR)XDR)X4C!X@5(P>D;3`.4),````!("<J)TDF-#!!)B?!(P>X"
M2<'@'HG*20GP2(G&B<!(`X0DR````$PQQD$Q]4B)UD^-E"JAZ]EN28G52,'F
M!4G![1M,">Z)]DV-+#),B>9)P>P"2,'F'D6)ZDP)YDV)Q$6)P$P#A"30````
M23'T1#'A38G42(V,"*'KV6Y,B=!)P>P;2,'@!4P)X(G`2`'(2(G12,'J`DC!
MX1Y!B<1("=%(B?*)]D@QRD$QU4R)XD^-K"BAZ]EN38G@2,'B!4G!Z!M,"<*)
MTDV-1!4`3(G22,'B'DG!Z@)%B<5(`[0DV````$P)TDF)RHG)2`.,).````!)
M,=)$,=!,C90&H>O9;DR)Z$R)[DC![AM(P>`%2`GPB<!)C30"3(G@2<'L`DC!
MX!Y!B?),">!)B=2)TD@#E"3H````23'$13'@38G43HV$`:'KV6Y,B=%)P>P;
M2,'A!4P)X8G)3`'!38GH2<'M`DG!X!Y!B<Q-">A)B<6)P$@#A"3P````33'%
M1#'N38GE2(VT,J'KV6Y,B>))P>T;2,'B!4P)ZHG22`'R3(G62<'J`DC!YAY!
MB=5,"=9-B<)%B<!),?),`X0D^````$0QT4V)ZDB-C`BAZ]EN3(GH2<'J&TC!
MX`5,"=")P$@!R$R)X4G![`)(P>$>08G"3`GA28GTB?9(`[0D``$``$DQS$0Q
MXDV-I!"AZ]EN3(G238G02<'H&TC!X@5,"<*)TDV-!!1,B>I)P>T"2,'B'D6)
MQ$P)ZDF)S8G)2`.,)`@!``!),=5$,>A,C:P&H>O9;DR)X$R)YDC![AM(P>`%
M2`GPB<!)C70%`$R)T$G!Z@)(P>`>08GU3`G028G2B=)),<)%,=!-B>I.C80!
MH>O9;DR)Z4G!ZAM(P>$%3`G12`.4)!`!``")R4P!P4V)X$G![`))P>`>08G*
M30G@28G$B<!(`X0D&`$``$TQQ$0QYDV)U$B-M#*AZ]EN3(G22<'L&TC!X@5,
M">*)TD@!\DR)[DG![0)(P>8>08G43`GN38G%18G`3`.$)"`!``!),?5$,>E-
MB>5(C8P(H>O9;DR)X$G![1M(P>`%3`GHB<!(`<A,B=%)P>H"2,'A'D&)Q4P)
MT4F)\DV)[HGV23'*2<'N&T0QTDV-A!"AZ]EN3(GJ2,'B!4P)\HG238TT$$R)
MXDF)R(G)2,'B'DG![`)%B?)(`[0D*`$``$P)XDV)U$@#C"0P`0``23'02<'L
M&T0QP$B-M`:AZ]EN3(G02,'@!4P)X(G`3(TD!DR)Z$G![0)(B=9(P>`>18G@
MB=)(`Y0D.`$``$P)Z$V)Q4@QQDG![1M!,?9*C;0QH>O9;DR)P4C!X05,">F)
MR4R-+`Y,B=%)P>H"2,'A'D2)[DP)T4F)PHG`2`.$)$`!``!),<I%,=1.C90B
MH>O9;DB)\DF)]$G![!M(P>(%3`GB38G$2<'H`DG!Y!Y!`=)-"<1)B<B)R4TQ
MX$2)XD4QQ4Z-A"BAZ]EN3(G038G52<'M&TC!X`5,">A,BZPD2`$``$6--`!)
MB?!(P>X"3(G@2<'@'DD)\$2)QDP)P$PAT$DA]$D)Q+C<O!N/20'%3`'I38GU
M20',3(GQ2<'M&TC!X05,">E%C2P,3(G12<'J`DC!X1Y,"=%)"<A)B<Q!B<I)
M(?1-(?!-">!,BZ0D4`$``$D!Q$P!XDV)[$D!T$R)ZDG![!M(P>(%3`GB18TD
M$$R)\DG![@)(P>(>3`GR28G.08G020G632'N3"'!3`GQ3(NT)%@!``!)`<9,
M`?9-B>9(`?%,B>9)P>X;2,'F!4P)]D2--#%,B>Y)P>T"2,'F'DP)[D@)\DF)
M]8GQ3"'B32'%3`GJ3(NL)&`!``!)`<5-`>I-B?5,`=)-B?))P>T;2<'B!4T)
MZD:-+!)-B>))P>P"2<'B'DT)XDF)]$2)TDT)U$TA]$@AUDP)YDR+I"1H`0``
M20'$30'@38GL3`'&38GH2<'L&TG!X`5-">!&C20&38GP2<'N`DG!X!Y-"?!-
M"<)-B<9$B<9)(=9-(>I-"?),B[0D<`$``$D!QDP!\4V)YDD!RDR)X4G![AM(
MP>$%3`GQ18TT"DR)Z4G![0)(P>$>3`GI38G%08G*20G-32'E32'030GH3(NL
M)'@!``!)`<5,`>I-B?5)`=!,B?))P>T;2,'B!4P)ZD6-+!!,B>)(P>(>2<'L
M`DP)XD@)T4F)U$&)T$TAU$PA\4P)X4R+I"2``0``20'$3`'F38GL2`'Q3(GN
M2<'L&TC!Y@5,">9$C20Q3(GV2<'N`DC!YAY,"?9)B=:)\4D)]DTA[D@ARDP)
M\DR+M"2(`0``20'&30'R38GF3`'238GB2<'N&TG!X@5-"?)&C30238GJ2<'M
M`DG!XAY-">I,"=9-B=5$B=))(<U,(>9,">Y,BZPDD`$``$D!Q4T!Z$V)]4P!
MQDV)\$G![1M)P>`%30GH1HTL!DV)X$G![`))P>`>30G@38G41(G&30G$32'T
M22'R30GB3(ND))@!``!)`<1,`>%-B>Q)`<I,B>E)P>P;2,'A!4P)X46-)`I,
MB?%)P>X"2,'A'DP)\4D)R$F)SD&)RDDA]DTAZ$T)\$R+M"2@`0``20'&3`'R
M38GF20'03(GB2<'N&TC!X@5,"?)%C3003(GJ2,'B'DG![0),">I)B<U!B=!)
M"=5-(>5,(<%,">E,BZPDJ`$``$D!Q4P![DV)]4@!\4R)]DG![1M(P>8%3`GN
M1(TL,4R)YDG![`)(P>8>3`GF2`GR28GTB?%-(<1,(?),">),BZ0DL`$``$D!
MQ$T!XDV)[$P!TDV)ZDG![!M)P>(%30GB38GT2<'N`DG!Y!Y!`=)-"?1)B?9$
MB>)-">9-(>Y((=9,"?9,B[0DN`$``$D!QDT!\$V)UDP!QDV)T$G![AM)P>`%
M30GP1HT\!DV)Z$G![0))P>`>30GH30G$38G%1(G&22'532'430GL3(NL),`!
M``!)`<5,`>E-B?U)`<Q,B?E)P>T;2,'A!4P)Z4$!S$R)T4G!Z@)(P>$>3`G1
M38G"08G.20G*32'Z32'P30G03(N4),@!``!)`<),`=)-B>))`=!,B>)(P>(%
M2<'J&TP)TDV)^DG![P))P>(>18TL$$T)^DP)T4R)TD6)UTPA\DPAX4@)T4B+
ME"30`0``2`'"2`'63(GJ2`'Q3(GN2,'B!4C![AM("?),B>9)P>P"2,'F'D2-
M!!%(BY0DV`$``$R)T4P)YD&)]$@)\4@!PDPAZ4TAXDP!\DD)RDR)P4D!TDR)
MPDC!Z1M(P>(%2`G*3(GI2<'M`HG22,'A'DP!TDP)Z4@#A"3@`0``2`G.28G-
M08G208G.3"'&32'E20GU2HTT.$R)P$G!Z`)(P>`>20'U38G73(G62<'O&TD)
MP$C!Y@6XUL%BRDPQP4P)_DV)QT6)P#'*2(N,).@!``")]DP![D@!P4&)]4D!
MS$J-#")-B>Q,B>I(P>H;2<'D!4D)U$R)TDG!Z@)(P>(>18GD20G22(N4)/`!
M``!)`<Q-,==$B>%(`<)$,?Y)`=9(B<I,`?9)B<Y(P>(%2<'N&TP)\HG23(TT
M%DR)ZDG![0)(P>(>18GW20G52(N4)/@!``!(`<)*C30"38G03(GZ18G233'H
M2,'J&T4QQ$Z-!"9-B?Q)P>0%20G42(G*2,'I`DC!XAY%B>1("<I(BXPD``(`
M`$T!Q$6)X$@!P4R)QDP!T4V)ZD6)[4DQTD4QUDZ-%#%-B<9,B<%(P>D;2<'F
M!4D)SDR)^4G![P)(P>$>18GV20G/2(N,)`@"``!-`=9%B?)(`<%,`>E)B=6)
MTDTQ_44Q[$Z-+"%-B=1,B=%(P>D;2<'D!4D)S$B+C"00`@``18GD30'L2<'H
M`D@!P4C!YAY(`=%,B?I%B>5,"<9%B?](,?)!,=9*C10Q38GN3(GI2,'I&TG!
MY@5)"<Y,B>E)P>T"18GV2,'A'DD!UDR)TDG!Z@),">E(P>(>18GP20G22(N4
M)!@"``!(`<),`?I)B?>)]DTQUT4Q_$Z-/")-B<1,B<)(P>H;2<'D!4D)U$B+
ME"0@`@``18GD2`'"30'\3(TL,DR)UD6)YT6)TD@QSDR)^D$Q]DC!ZAM+C70U
M`$V)_DG!Y@5)"=9,B<)%B?9)`?9(P>(>2(NT)#`"``!)P>@"18GU20G02(N4
M)"@"``!(`<9(`<),`=))B<J)R4TQPD4QU$Z-%")-B>Q,B>I(P>H;2<'D!4D)
MU$R)^DG![P)(P>(>18GD3`GZ3(T\#DR)P4T!U$@QT46)XD6)P$$QSDR)UDN-
M##=-B=9(P>X;2<'F!4D)]DR)UD6)]DD!SDR)Z4G![0)(P>$>18GW20G-2(N,
M)#@"``!(`<%,`<%)B=")TDTQZ$4QQ$Z-!"%-B?Q,B?E(P>D;2<'D!4D)S$B+
MC"1``@``18GD30'$2`'!2<'J`DC!YAY%B>!,"=9,C1013(GJ3(G!2#'R2,'I
M&T6)[4$QUDN-%#)-B<9)P>8%20G.3(G!2<'H`D6)]DC!X1Y)`=9,B?I)P>\"
M3`G!2,'B'D6)\DD)UTB+E"1(`@``2`'"3`'J28GUB?9-,?U%,>Q.C2PB38G4
M3(G22,'J&TG!Y`5)"=1(BY0D4`(``$6)Y$@!PDT![$R-!#),B?Y%B>5%B?](
M,<Y,B>I!,?9(P>H;2XTT,$V)[DG!Y@5)"=9,B=)%B?9)`?9(P>(>2(NT)&`"
M``!)P>H"18GP20G22(N4)%@"``!(`<9(`<))`==(B<J)R4PQTD$QU$R)PDT!
M_$V)QTC!ZAM)P><%20G73(GJ2<'M`DC!XAY%B?],">I,C2P.3(G130'\2#'1
M18GG18G203'.3(G^2XU,-0!-B?Y(P>X;2<'F!4D)]D6)]DD!SDR)P4G!Z`)(
MP>$>1(GV20G(2(N,)&@"``!(`<%)`<I(B=&)TDPQP4$QS$B)\4T!U$F)\DC!
MZ1M)P>(%20G*3(GY2<'O`DC!X1Y%B=))"<](BXPD<`(``$T!XD6)U$@!P4R-
M+!%,B<),B>%%B<!,,?I(P>D;03'62XU4-0!-B>9)P>8%20G.18GV20'62(GR
M2,'N`DC!XAY$B?%("=9(BY0D>`(``$@!PD@#A"2``@``20'03(GZ20'!18G_
M2#'R2(GP30'/03'22(G*30'028G*2,'B!4G!ZAM,"=)!`=!,B>))P>P"2,'B
M'DV)P4D)U$R)PDPQX$$QQDG!X05!`>A!`=Q(P>H;2XT$-P-W($R)1PA)"=%,
MB6<800'!2(G(2,'I`DB)=R!(P>`>3(D/2`G!00'+3(E?$$B+A"2(`@``9$@K
M!"4H````=`7H3=+__TB!Q)@"``!;74%<05U!7D%?PU"_@````.C0S___NHFK
MS>^Y_MRZF+[PX=+#2,<``2-%9TB)4`A(B4@02,=`&'94,A!(B7`@2,=`*```
M``!(QT`P`````,=`>`````!:PT%62&/"055!5%5(B<532(M/*$B)^XT4P4@Y
MT78$2/]',$C!Z!U(`4,P2&-#>$R-8SA(B5,HA<!T3[I`````*<(YU0].U4P!
MX$ACRD@Y\',+2(T\"$@Y_G,"#PM,C2P.2#GP=@5,.>AR\$B)Q_.DBT-X`=")
M0WB#^$!U<TB)WRG5Z`GI__],B>Y,C6MX@_T_?C),.>9V!4PY[G*^3(UV0$DY
M]'8%33GT<K"Y$````$R)YX/M0/.E2(G?Z-#H__],B?;KR4ACS4PYYG8)28T$
M#$@YQG*%3#GF<PU(C00.23G$#X)S____3(GG\Z2):WA;74%<05U!7L-!5DR-
M=CA!54%454B)]5-(BT8H2(G[1(MF*$2+;C!(P>@#@^`_00_,00_-C7`!2)A(
M8];&1`4X@$P!\H/^.'XDN4`````QP$B)URGQ\ZI(B>_H0>C__[D.````,<!,
MB??SJ^L.N3@````QP$B)URGQ\ZI$B6UP2(GO1(EE=.@5Z/__2(M%`$B)[TC!
MZ!B(`TB+10!(P>@0B$,!2(M%`$C!Z`B(0P)(BT4`B$,#2(M%"$C!Z!B(0P1(
MBT4(2,'H$(A#!4B+10A(P>@(B$,&2(M%"(A#!TB+11!(P>@8B$,(2(M%$$C!
MZ!"(0PE(BT402,'H"(A#"DB+11"(0PM(BT482,'H&(A##$B+11A(P>@0B$,-
M2(M%&$C!Z`B(0PY(BT48B$,/2(M%($C!Z!B(0Q!(BT4@2,'H$(A#$4B+12!(
MP>@(B$,22(M%((A#$UM=05Q!74%>Z0W/__]F+@\?A```````#Q\`2(L%$6@`
M`$B#^/]T,U5(B>532(T=_V<``$B#[`@/'P#_T$B+0_A(@^L(2(/X_W7P2(M=
M^,G#9BX/'X0``````,-0Z.G1__]8PP``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````4$%27U1-4$1)4@!414U01$E2`%1-4``N+@`E<R\E<P!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`97AE
M`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,
M24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'
M3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T`+W1M<`!54T52`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E
M<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`U,`!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL
M96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D
M8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*
M8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M
M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG
M+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ
M92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@
M)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M
M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*
M?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?
M<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M
M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S
M(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").
M(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER
M95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T
M<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E"
M.B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT
M("1F:"`D:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D
M9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID
M:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B
M4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X
M=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M
M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E
M="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S
M>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E
M<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@
M>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S
M=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*
M:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B
M+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,
M13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\
M96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT
M*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I
M;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*
M;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M
M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?
M34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&
M2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI
M8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C
M=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F
M:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I
M="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*
M;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M
M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<
M,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG
M97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N
M*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]
M('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M
M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E
M;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@
M)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?
M5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92![
M"B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%
M1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T
M92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]
M"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%
M04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE
M;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU
M92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````'!E<FQX<VDN8P``
M``$;`SO@````&P```+R"___\````7(;__R0!``!\AO__U`0``,&)__\\`0``
M2HK__X0!``""BO__G`$``/"*___$`0``)8S__P@"``"GC/__)`(``$..__]H
M`@``;H[__X`"``"RCO__F`(``)V/___,`@``HH___^`"``!"D?__+`,``%B1
M__]``P```I+__V0#``"AD___@`,``.F3__^8`P```)3__[`#``"*E/__Z`,`
M`%":__]D!```CIW__Z`$``#=G?___`0```&T__](!0``3[3__V`%``!&M?__
MG`4``!0``````````7I2``%X$`$;#`<(D`$``"0````<````N('__Z`#````
M#A!&#AA*#PMW"(``/QH[*C,D(@`````4````1````#"%__\8````````````
M``!$````7````'V(__^)`````$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!
M#CB#!T$.0`)M#CA$#C!!#BA"#B!"#AA"#A!"#@@4````I````+Z(__\X````
M`$0.(',."``D````O````-Z(__]N`````$$.$(8"00X8@P-'#C`"8@X800X0
M00X(0````.0````DB?__-0$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&
M1P[0`0,=`0XP00XH00X@0@X80@X00@X(```8````*`$``!6*__^"`````$<.
MP`$">@X(````0````$0!``![BO__G`$```!"#A".`D(.&(T#0@X@C`1!#BB&
M!40.,(,&1PY``X$!#C!!#BA!#B!"#AA"#A!"#@@````4````B`$``-.+__\K
M`````$$.$%0."``4````H`$``.:+__]$`````$$.$&H."``P````N`$``!*,
M___K`````$(.$(P"00X8A@-!#B"#!$<.L$`"VPX@00X800X00@X(````$```
M`.P!``#)C/__!0````````!(``````(``+J,__^@`0```$(.$(\"0@X8C@-"
M#B"-!$P.*(P%00XPA@9$#CB#!T<.X"$#=`$..$0.,$$.*$(.($(.&$(.$$(.
M"```$````$P"```.CO__%@`````````@````8`(``!".__^J`````$H.$(8"
M`DP*Q@X(0@L"10X(0<88````A`(``):.__^?`0```$0.0`.:`0X(````%```
M`*`"```9D/__2`````!*#A!V#@@`%````+@"``!)D/__%P````!!#A!5#@@`
M-````-`"``!(D/__B@````!"#A",`DT.&(8#00X@@P0"9`H.&$@.$$0."$4+
M00X800X00@X(``!X````"`,``)J0___&!0```$(.$(\"3@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!TH.D(,"`IL*#CA$#C!!#BA"#B!"#AA"#A!"#@A%"P..
M!`Z8@P)*#J"#`E`.F(,"00Z0@P("0@XX1`XP00XH0@X@0@X80@X00@X(````
M.````(0#``#DE?__/@,```!"#A"-`D(.&(P#00X@A@1!#BB#!4$.,`,P`PXH
M00X@00X80@X00@X(````,````,`#``#FF/__3P````!!#A"&`D0.&(,#00X@
M>PH.&$0.$$$."$4+00X800X000X(`"0```#T`P``H('__[(!````0@X0C`)$
M#C`#I@$.$$4."`````````!(````'`0``-F8__\D%@```$(.$(\"1`X8C@-"
M#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#!A8..$$.,$$.*$(.($(.&$(.$$(.
M"```%````&@$``"QKO__3@````!!#A`"3`X(.````(`$``#GKO__]P````!"
M#A".`D4.&(T#0@X@C`1!#BB&!40.,(,&`N$.*$$.($(.&$(.$$(."```.```
M`+P$``"BK___60$```!"#A".`D8.&(T#0@X@C`1!#BB&!40.,(,&`SX!#BA!
M#B!"#AA"#A!"#@@`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`/__________``````````#__________P`````````````````````!````
M``````@#`````````0`````````3`P````````\`````````/@0````````,
M```````````@````````#0````````!!5````````/7^_V\`````D`(`````
M```%`````````+@,````````!@````````"(`P````````H`````````7`0`
M```````+`````````!@`````````%0````````````````````,`````````
MX+T````````"`````````%@%````````%``````````'`````````!<`````
M````X!(````````'`````````!@1````````"`````````#(`0````````D`
M````````&``````````8````````````````````^___;P`````!```(````
M`/G__V\`````!P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$"\`````````````````````````````"8@````````-B``````
M``!&(````````%8@````````9B````````!V(````````(8@````````EB``
M``````"F(````````+8@````````QB````````#6(````````.8@````````
M]B`````````&(0```````!8A````````)B$````````V(0```````$8A````
M````5B$```````!F(0```````'8A````````AB$```````"6(0```````*8A
M````````MB$```````#&(0```````-8A````````YB$```````#V(0``````
M``8B````````%B(````````F(@```````#8B````````1B(```````!6(@``
M`````&8B````````=B(```````"&(@```````)8B````````IB(```````"V
M(@```````,8B````````UB(```````#F(@```````/8B````````!B,`````
M```6(P```````"8C````````-B,```````!&(P```````%8C````````9B,`
M``````!V(P```````(8C````````EB,```````"F(P``````````````````
M````````````````````````````````````````````````````````````
M````````````````P`````````````````````````````````````````!@
M````````\F`````````+8`````````1A````````$V``````````````````
M`/____\`````N6(```````!'0T,Z("A!;'!I;F4@,3`N,BXP*2`Q,"XR+C``
M`"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN
M:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O
M<G,`+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@````````!P`@```````'`"
M````````&0````````````````````$````````````````````3````]O__
M;P(`````````D`(```````"0`@```````/@``````````P`````````(````
M````````````````'0````L````"`````````(@#````````B`,````````P
M"0````````0````!````"``````````8`````````"4````#`````@``````
M``"X#````````+@,````````7`0```````````````````$`````````````
M```````M````!`````(`````````&!$````````8$0```````,@!````````
M`P`````````(`````````!@`````````-P````0```!"`````````.`2````
M````X!(```````!8!0````````,````3````"``````````8`````````$$`
M```!````!@``````````(``````````@````````#0``````````````````
M``$````````````````````\`````0````8`````````$"`````````0(```
M`````*`#```````````````````0`````````!``````````1P````$````&
M`````````+`C````````L",````````8````````````````````"```````
M```(`````````%`````!````!@````````#0(P```````-`C````````<3``
M`````````````````!````````````````````!6`````0````8`````````
M050```````!!5`````````@````````````````````!````````````````
M````7`````$````"``````````!@`````````&````````!2/0``````````
M````````"````````````````````&0````!`````@````````!4G0``````
M`%2=````````Y`````````````````````0```````````````````!R````
M`0````(`````````.)X````````XG@```````/@$```````````````````(
M````````````````````?`````$````#`````````!B\````````&*P`````
M```0````````````````````"````````````````````(,````!`````P``
M```````HO````````"BL````````$`````````````````````@`````````
M``````````"*`````0````,`````````.+P````````XK`````````@`````
M```````````````(````````````````````EP````8````#`````````$"\
M````````0*P```````"@`0````````0`````````"``````````0````````
M`$L````!`````P````````#@O0```````."M````````(`(`````````````
M``````@`````````"`````````"@`````0````,``````````,``````````
ML````````&`````````````````````@````````````````````I@````@`
M```#`````````&#`````````8+````````"H$```````````````````(```
M`````````````````*L````!````,````````````````````&"P````````
M'`````````````````````$``````````0`````````!`````P``````````
M``````````````!\L````````+0````````````````````!````````````
&````````
